@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.517";
+our $VERSION = "0.518";
 
 1;
 
@@ -17,13 +17,14 @@ Sys class in L<SPVM> has methods to call system calls for file IO, sockets, user
   use Sys;
   
   my $fd_ref = [(Sys::IO::FileStream)undef];
-  Sys->open($fd_ref, "<", $path);
+  my $file = "a.txt";
+  Sys->open($fd_ref, "<", $file);
   
   Sys->mkdir("foo");
   
   Sys->rmdir("foo");
   
-  my $path = Sys->env("PATH");
+  my $env_path = Sys->env("PATH");
   
   my $process_id = Sys->process_id;
 
@@ -49,9 +50,9 @@ Returns the L<stderr|SPVM::Document::NativeAPI/"spvm_stderr"> opened by the SPVM
 
 =head2 open
 
-C<static method open : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $file_name : string);>
+C<static method open : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $file : string);>
 
-Opens a file given the open mode $open_mode and the file name $file_name. 
+Opens a file given the open mode $open_mode and the file name $file. 
 
 The opened file stream is set to $stream_ref at index 0.
 
@@ -99,9 +100,9 @@ Exceptions thrown by L<Sys::IO#fileno|SPVM::Sys::IO/"fileno"> method could be th
 
 =head2 read
 
-C<static method read : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $length : int, $buf_offset : int = 0);>
+C<static method read : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buffer : mutable string, $length : int, $buffer_offset : int = 0);>
 
-Reads data from the file stream $stream by the $length, and saves it to the buffer $buf at offset $buf_offset.
+Reads data from the file stream $stream by the $length, and saves it to the buffer $buffer at offset $buffer_offset.
 
 This method calls L<Sys::IO#fread|SPVM::Sys::IO/"fread"> method.
 
@@ -249,9 +250,9 @@ Exceptions thrown by L<Sys::IO#ftell|SPVM::Sys::IO/"ftell"> method could be thro
 
 =head2 sysopen
 
-C<static method sysopen : void ($fd_ref : int*, $path : string, $flags : int, $mode : int = 0);>
+C<static method sysopen : void ($fd_ref : int*, $file : string, $flags : int, $mode : int = 0);>
 
-Opens a file given, the file path $path, the mode $flags and the mode $mode.
+Opens a file given, the file path $file, the mode $flags and the mode $mode.
 
 The file descriptor of the opened file is set to the value reffered by $fd_ref.
 
@@ -263,9 +264,9 @@ Exceptions thrown by L<Sys::IO#open|SPVM::Sys::IO/"open"> method could be thrown
 
 =head2 sysread
 
-C<static method sysread : int ($fd : int, $buf : mutable string, $length : int, $buf_offset : int = 0);>
+C<static method sysread : int ($fd : int, $buffer : mutable string, $length : int, $buffer_offset : int = 0);>
 
-Reads data from the file stream $stream by the $length, and saves it to the buffer $buf from the offset $buf_offset.
+Reads data from the file stream $stream by the $length, and saves it to the buffer $buffer from the offset $buffer_offset.
 
 Exceptions:
 
@@ -273,9 +274,9 @@ Exceptions thrown by L<Sys::IO#read|SPVM::Sys::IO/"read"> method could be thrown
 
 =head2 syswrite
 
-C<static method syswrite : int ($fd : int, $buf : string, $length : int = -1, $buf_offset : int = 0);>
+C<static method syswrite : int ($fd : int, $buffer : string, $length : int = -1, $buffer_offset : int = 0);>
 
-Writes data to the file stream $stream by the $length from the buffer $buf at offset $buf_offset.
+Writes data to the file stream $stream by the $length from the buffer $buffer at offset $buffer_offset.
 
 Exceptions:
 
@@ -317,9 +318,9 @@ Exceptions thrown by L<Sys::IO#flock|SPVM::Sys::IO/"flock"> method could be thro
 
 =head2 mkdir
 
-C<static method mkdir : void ($path : string, $mode : int);>
+C<static method mkdir : void ($dir : string, $mode : int);>
 
-Creates the directory given the path $path and the mode $mode.
+Creates the directory given the path $dir and the mode $mode.
 
 The permissions of the created directory are ($mode & ~L<umask|/"umask"> & 0777).
 
@@ -341,7 +342,7 @@ Exceptions thrown by L<Sys::IO#umask|SPVM::Sys::IO/"umask"> method could be thro
 
 =head2 unlink
 
-C<static method unlink : void ($pathname : string);>
+C<static method unlink : void ($file : string);>
 
 Deletes a file.
 
@@ -353,9 +354,9 @@ Exceptions thrown by the L<Sys::IO::Windows#unlink|SPVM::Sys::IO::Windows/"unlin
 
 =head2 rename
 
-C<static method rename : void ($oldpath : string, $newpath : string);>
+C<static method rename : void ($old_path : string, $new_path : string);>
 
-Raname the file name from the old name $oldpath to the new name $newpath.
+Raname the file name from the old name $old_path to the new name $new_path.
 
 In Windows, this method calls L<Sys::IO::Windows#rename|SPVM::Sys::IO::Windows/"rename"> method , otherwise calls L<Sys::IO#rename|SPVM::Sys::IO/"rename"> method.
 
@@ -365,9 +366,9 @@ Exceptions thrown by the L<Sys::IO::Windows#rename|SPVM::Sys::IO::Windows/"renam
 
 =head2 rmdir
 
-C<static method rmdir : void ($path : string);>
+C<static method rmdir : void ($dir : string);>
 
-Deletes the directory given the path $path.
+Deletes the directory given the path $dir.
 
 Exceptions:
 
@@ -375,9 +376,9 @@ Exceptions thrown by L<Sys::IO#rmdir|SPVM::Sys::IO/"rmdir"> method could be thro
 
 =head2 chdir
 
-C<static method chdir : void ($path : string);>
+C<static method chdir : void ($dir : string);>
 
-Changes the working directory to the path $path.
+Changes the working directory to the path $dir.
 
 Exceptions:
 
@@ -385,9 +386,9 @@ Exceptions thrown by L<Sys::IO#chdir|SPVM::Sys::IO/"chdir"> method could be thro
 
 =head2 chmod
 
-C<static method chmod : void ($mode :int, $path : string);>
+C<static method chmod : void ($mode :int, $file : string);>
 
-Changes the permissions of the file $path to the permission $mode.
+Changes the permissions of the file $file to the permission $mode.
 
 Exceptions:
 
@@ -395,9 +396,9 @@ Exceptions thrown by L<Sys::IO#chmod|SPVM::Sys::IO/"chmod"> method could be thro
 
 =head2 chown
 
-C<static method chown : void ($owner : int, $group : int, $path : string);>
+C<static method chown : void ($owner : int, $group : int, $file : string);>
 
-Changes the owner and the group of the file $path to $owner and $group.
+Changes the owner and the group of the file $file to $owner and $group.
 
 Exceptions:
 
@@ -417,9 +418,9 @@ Exceptions thrown by L<Sys::IO#readlink|SPVM::Sys::IO/"readlink"> method or L<Sy
 
 =head2 symlink
 
-C<static method symlink : int ($oldpath : string, $newpath : string);>
+C<static method symlink : int ($old_path : string, $new_path : string);>
 
-Creates a path $newpath symbolically linked to the path $oldpath.
+Creates a path $new_path symbolically linked to the path $old_path.
 
 In Windows thie method calls L<Sys::IO::Windows#symlink|SPVM::Sys::IO::Windows/"symlink"> method , otherwise calls L<Sys::IO#symlink|SPVM::Sys::IO/"symlink"> method .
 
@@ -439,11 +440,11 @@ Exceptions thrown by L<Sys::IO#ftruncate|SPVM::Sys::IO/"ftruncate"> method could
 
 =head2 opendir
 
-C<static method opendir : void ($dh_ref : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>[], $dir : string);>
+C<static method opendir : void ($dir_stream_ref : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>[], $dir : string);>
 
 Opens the directory stream given the directory $dir.
 
-The opened directory stream is set to $dh_ref at index 0.
+The opened directory stream is set to $dir_stream_ref at index 0.
 
 Exceptions:
 
@@ -561,7 +562,7 @@ Exceptions thrown by L<Sys::IO#pclose|SPVM::Sys::IO/"pclose"> method or L<Sys::I
 
 =head2 select
 
-C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double = 0);>
+C<static method select : int ($read_fds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $write_fds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $except_fds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double = 0);>
 
 Calls L<Sys::Select#select|SPVM::Sys::Select/"select"> method and returns its return value.
 
@@ -947,9 +948,9 @@ Works just like L</"localtime">, but the returned values are for the UTC time zo
 
 =head2 utime
 
-C<static method utime : void ($atime : long, $mtime : long, $filename : string);>
+C<static method utime : void ($atime : long, $mtime : long, $file : string);>
 
-Changes the access time and the modification time of the inode specified by the file $filename given the access time $atime and the modification time $mtime.
+Changes the access time and the modification time of the inode specified by the file $file given the access time $atime and the modification time $mtime.
 
 If $atime < 0 and $mtime < 0, changes the access time and the modification time to the current time..
 
@@ -959,9 +960,9 @@ Exceptions thrown by L<Sys::Time#utime|SPVM::Sys::Time/"utime"> method could be
 
 =head2 stat
 
-C<static method stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
+C<static method stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($file : string);>
 
-Returns information about a file $path.
+Returns information about a file $file.
 
 Exceptions:
 
@@ -969,9 +970,9 @@ Exceptions thrown by L<Sys::IO::Stat#stat|SPVM::Sys::IO::Stat/"stat"> method cou
 
 =head2 lstat
 
-C<static method lstat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
+C<static method lstat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($file : string);>
 
-Identical to L</"stat">, except that if path $path is a symbolic link(or directory junction only in Windows), then the link itself is stat-ed, not the file that it refers to.
+Identical to L</"stat">, except that if path $file is a symbolic link(or directory junction only in Windows), then the link itself is stat-ed, not the file that it refers to.
 
 In Windows, this method calls the L<lstat|SPVM::Sys::IO::Windows/"lstat"> method, otherwise calls the L<lstat|SPVM::Sys::IO::Stat/"lstat"> method.
 
@@ -1045,15 +1046,15 @@ If the OS name could not be determined, an exception is thrown.
 
 =head2 socket
 
-C<static method socket : void ($sockfd_ref : int*, $domain : int, $type : int, $protocol : int);>
+C<static method socket : void ($socket_fd_ref : int*, $domain : int, $type : int, $protocol : int);>
 
 Opens a socket given the domain $domain, the type $type, and the protocal $protocol.
 
-The created socket file descriptor is set to the value referenced by $sockfd_ref.
+The created socket file descriptor is set to the value referenced by $socket_fd_ref.
 
 This method calls L<Sys::Socket#socket|SPVM::Sys::Socket/"socket"> method.
 
-If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced by $sockfd_ref using L</"fcntl">.
+If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced by $socket_fd_ref using L</"fcntl">.
 
 Exceptions:
 
@@ -1061,7 +1062,7 @@ Exceptions thrown by L<Sys::Socket#socket|SPVM::Sys::Socket/"socket"> method cou
 
 =head2 connect
 
-C<static method connect : void ($sockfd : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
+C<static method connect : void ($socket_fd : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
 
 Attempts to connect to a remote socket, just like the C<connect> system call.
 
@@ -1073,9 +1074,9 @@ Exceptions thrown by L<Sys::Socket#connect|SPVM::Sys::Socket/"connect"> method c
 
 =head2 bind
 
-C<static method bind : void ($sockfd : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
+C<static method bind : void ($socket_fd : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
 
-Binds a network address $sockaddr to the socket $sockfd.
+Binds a network address $sockaddr to the socket $socket_fd.
 
 This method calls L<Sys::Socket#bind|SPVM::Sys::Socket/"bind"> method.
 
@@ -1085,7 +1086,7 @@ Exceptions thrown by L<Sys::Socket#bind|SPVM::Sys::Socket/"bind"> method could b
 
 =head2 listen
 
-C<static method listen : void ($sockfd : int, $backlog : int);>
+C<static method listen : void ($socket_fd : int, $backlog : int);>
 
 Does the same thing that the C<listen> system call does.
 
@@ -1097,17 +1098,17 @@ Exceptions thrown by L<Sys::Socket#listen|SPVM::Sys::Socket/"listen"> method cou
 
 =head2 accept
 
-C<static method accept : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($new_sockfd_ref : int*, $sockfd : int);>
+C<static method accept : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($new_socket_fd_ref : int*, $socket_fd : int);>
 
 Accepts an incoming socket connect, just as the C<accept> system call does. Returns the packed address.
 
-A new connected socket file descriptor is set to the value referenced by $new_sockfd_ref.
+A new connected socket file descriptor is set to the value referenced by $new_socket_fd_ref.
 
 Thie methods calls L<Sys::Socket#accept|SPVM::Sys::Socket/"accept"> method.
 
 The returned packed address is upgraded to a child class of the L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> using L<upgrade|SPVM::Sys::Socket::Sockaddr/"upgrade"> method.
 
-If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced by $new_sockfd_ref using L</"fcntl">.
+If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced by $new_socket_fd_ref using L</"fcntl">.
 
 Exceptions:
 
@@ -1115,23 +1116,27 @@ Exceptions thrown by L<Sys::Socket#accept|SPVM::Sys::Socket/"accept"> method cou
 
 =head2 recv
 
-C<static method recv : int ($sockfd : int, $buf : mutable string, $len : int, $flags : int, $buf_offset : int = 0);>
+C<static method recv : int ($socket_fd : int, $buffer : mutable string, $length : int, $flags : int, $buffer_offset : int = 0);>
 
 Receives a message on a socket.
 
-This method calls L<Sys::Socket#recv|SPVM::Sys::Socket/"recv"> method.
+This method calls L<Sys::Socket#recv|SPVM::Sys::Socket/"recv"> method given the arguments given to this method and returns its return value.
 
 Exceptions:
 
 Exceptions thrown by L<Sys::Socket#recv|SPVM::Sys::Socket/"recv"> method could be thrown.
 
-=head2 recv
+=head2 recvfrom
 
-C<static method recvfrom : int ($sockfd : int, $buf : mutable string, $len : int, $flags : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $buf_offset : int = 0);>
+C<static method recvfrom : int ($socket_fd : int, $buffer : mutable string, $length : int, $flags : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $buffer_offset : int = 0);>
 
-Receives a message on a socket.
+Receives a message on a socket given the peer socket address $sockaddr for output.
 
-This method calls L<Sys::Socket#recvfrom|SPVM::Sys::Socket/"recvfrom"> method.
+This method calls L<Sys::Socket#recvfrom|SPVM::Sys::Socket/"recvfrom"> method given the arguments given to this method and returns its return value.
+
+$addrlen is set to the return value of L<Sys::Socket::Sockaddr::Storage#size|SPVM::Sys::Socket::Sockaddr::Storage/"size"> method.
+
+If $sockaddr is given, $sockaddr is upgraded by calling L<Sys::Socket::Sockaddr#upgrade|SPVM::Sys::Socket::Sockaddr/"upgrade"> method.
 
 Exceptions:
 
@@ -1139,23 +1144,37 @@ Exceptions thrown by L<Sys::Socket#recvfrom|SPVM::Sys::Socket/"recvfrom"> method
 
 =head2 send
 
-C<static method send : int ($sockfd : int, $buf : string, $flags : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> = undef, $len : int = -1, $buf_offset : int = 0)>
+C<static method send : int ($socket_fd : int, $buffer : string, $flags : int, $length : int = -1, $buffer_offset : int = 0);>
 
 Sends a message on a socket.
 
-If $len is less than 0, The length of $buffer is set to $len.
+This method calls L<Sys::Socket#send|SPVM::Sys::Socket/"send"> method given the arguments given to this method and returns its return value.
 
-If $sockaddr is undef, This method calls L<Sys::Socket#send|SPVM::Sys::Socket/"send"> method, otherwise calls L<Sys::Socket#sendto|SPVM::Sys::Socket/"sendto"> method.
+If $length is less than 0, $length is set to the length of $buffer.
 
 Exceptions:
 
-Exceptions thrown by the L<send|SPVM::Sys::Socket/"send"> method or L<Sys::Socket#sendto|SPVM::Sys::Socket/"sendto"> method could be thrown.
+Exceptions thrown by L<Sys::Socket#sendto|SPVM::Sys::Socket/"send"> method could be thrown.
+
+=head2 sendto
+
+C<static method sendto : int ($socket_fd : int, $buffer : string, $flags : int, $sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $length : int = -1, $buffer_offset : int = 0);>
+
+Sends a message on a socket given the peer socket address $sockaddr.
+
+This method calls L<Sys::Socket#sendto|SPVM::Sys::Socket/"sendto"> method given the arguments given to this method and returns its return value.
+
+If $length is less than 0, $length is set to the length of $buffer.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::Socket#sendto|SPVM::Sys::Socket/"sendto"> method could be thrown.
 
 =head2 shutdown
 
-C<static method shutdown : void ($sockfd : int, $how : int);>
+C<static method shutdown : void ($socket_fd : int, $how : int);>
 
-Shuts down a socket  connection $sockfd in the manner indicated by $how.
+Shuts down a socket  connection $socket_fd in the manner indicated by $how.
 
 This method calls L<Sys::Socket#shutdown|SPVM::Sys::Socket/"shutdown"> method.
 
@@ -1165,9 +1184,9 @@ Exceptions thrown by L<Sys::Socket#shutdown|SPVM::Sys::Socket/"shutdown"> method
 
 =head2 getpeername
 
-C<static method getpeername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($sockfd : int);>
+C<static method getpeername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($socket_fd : int);>
 
-Returns the packed sockaddr address of the other end of the socket connection $sockfd.
+Returns the packed sockaddr address of the other end of the socket connection $socket_fd.
 
 This method calls L<Sys::Socket#getpeername|SPVM::Sys::Socket/"getpeername"> method.
 
@@ -1179,9 +1198,9 @@ Exceptions thrown by L<Sys::Socket#getpeername|SPVM::Sys::Socket/"getpeername">
 
 =head2 getsockname
 
-C<static method getsockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($sockfd : int)>
+C<static method getsockname : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($socket_fd : int)>
 
-Returns the packed sockaddr address of this end of the socket connection $sockfd.
+Returns the packed sockaddr address of this end of the socket connection $socket_fd.
             
 Thie method calls L<Sys::Socket#getsockname|SPVM::Sys::Socket/"getsockname"> method.
 
@@ -1193,19 +1212,19 @@ Exceptions thrown by L<Sys::Socket#getsockname|SPVM::Sys::Socket/"getsockname">
 
 =head2 socketpair
 
-C<static method socketpair : void ($sock_fd1_ref : int*, $sock_fd2_ref : int*, $domain : int, $type : int, $protocol : int);>
+C<static method socketpair : void ($socket_fd1_ref : int*, $socket_fd2_ref : int*, $domain : int, $type : int, $protocol : int);>
 
 Creates an unnamed pair of sockets in the specified domain, of
 the specified type. The domain $domain, the type $type, the protocal $protocol are specified the
 same as for the syscall of the same name.
 
-The opened reading file descripor is set to the value referenced by $sock_fd1_ref.
+The opened reading file descripor is set to the value referenced by $socket_fd1_ref.
 
-The opened writing file descripor is set to the value referenced by $sock_fd2_ref.
+The opened writing file descripor is set to the value referenced by $socket_fd2_ref.
 
 This method calls L<Sys::Socket#socketpair|SPVM::Sys::Socket/"socketpair"> method .
 
-If available, C<FD_CLOEXEC> is set to the file descriptor of the value referenced by $sock_fd1_ref and the value referenced by $sock_fd2_ref.
+If available, C<FD_CLOEXEC> is set to the file descriptor of the value referenced by $socket_fd1_ref and the value referenced by $socket_fd2_ref.
 
 Exceptions:
 
@@ -1213,7 +1232,7 @@ Exceptions thrown by L<Sys::Socket#socketpair|SPVM::Sys::Socket/"socketpair"> me
 
 =head2 setsockopt
 
-C<static method setsockopt : void ($sockfd : int, $level : int, $optname : int, $optval : object of string|Int);>
+C<static method setsockopt : void ($socket_fd : int, $level : int, $option_name : int, $option_value : object of string|Int);>
 
 Sets the socket option requested.
 
@@ -1221,17 +1240,17 @@ This method calls L<Sys::Socket#getsockopt|SPVM::Sys::Socket/"getsockopt"> metho
 
 Exceptions:
 
-$optval must be defined. Otherwise an exception is thrown.
+$option_value must be defined. Otherwise an exception is thrown.
 
-The type of \$optval must be the Int or string type.
+The type of \$option_value must be the Int or string type.
 
 Exceptions thrown by L<Sys::Socket#getsockopt|SPVM::Sys::Socket/"getsockopt"> method could be thrown.
 
 =head2 getsockopt
 
-C<static method getsockopt : string ($sockfd : int, $level : int, $optname : int, $optlen : int = -1);>
+C<static method getsockopt : string ($socket_fd : int, $level : int, $option_name : int, $option_value_length : int = -1);>
 
-If $optlen is less than 0, it is set to 4.
+If $option_value_length is less than 0, it is set to 4.
 
 This method calls L<Sys::Socket#getsockopt|SPVM::Sys::Socket/"getsockopt"> method.
 
@@ -1250,9 +1269,9 @@ Exceptions thrown by L<Sys::Socket#getsockopt|SPVM::Sys::Socket/"getsockopt"> me
 
 =head2 signal
 
-C<static method signal : void ($signum : int, $handler_name : string);>
+C<static method signal : void ($signal_number : int, $handler_name : string);>
 
-Sets a signal handler with its name $handler_name for the given signal number $signum.
+Sets a signal handler with its name $handler_name for the given signal number $signal_number.
 
 If $handler_name is "DEFAULT", the signal handler is L<"SIG_DFL"|SPVM::Sys::Signal/"SIG_DFL">.
 
@@ -1268,9 +1287,9 @@ The exceptions thrown by L<Sys::Signal#signal|SPVM::Sys::Signal/"signal"> method
 
 =head2 kill
 
-C<static method kill : void ($sig : int, $pid : int);>
+C<static method kill : void ($signal_number : int, $process_id : int);>
 
-Send a signal $sig to the process whose process ID is $pid.
+Send a signal $signal_number to the process whose process ID is $process_id.
 
 See L<Sys::Signal#kill|SPVM::Sys::Signal/"kill"> method in detail.
 
@@ -1282,7 +1301,7 @@ The exceptions thrown by L<Sys::Signal#alarm|SPVM::Sys::Signal/"alarm"> method c
 
 The exceptions thrown by L<Sys::Signal#raise|SPVM::Sys::Signal/"raise"> method could be thrown.
 
-$pid must be equal to Sys->process_id in Windows. Otherwise an exception is thrown.
+$process_id must be equal to Sys->process_id in Windows. Otherwise an exception is thrown.
 
 =head2 alarm
 
@@ -1320,7 +1339,7 @@ Exceptions thrown by L<Sys::Process#getpriority|SPVM::Sys::Process/"getpriority"
 
 =head2 setpriority
 
-C<static method setpriority : void ($which : int, $who : int, $prio : int)>
+C<static method setpriority : void ($which : int, $who : int, $priority : int)>
 
 Sets the scheduling priority of the process, process group, or user, as indicated by $which and $who is obtained.
 
@@ -1372,9 +1391,9 @@ Exceptions thrown by L<Sys::Process#wait|SPVM::Sys::Process/"wait"> method could
 
 =head2 waitpid
 
-C<static method waitpid : int ($pid : in, $options : int, $wstatus_ref : int*);>
+C<static method waitpid : int ($process_id : in, $options : int, $wstatus_ref : int*);>
 
-Same as the L</"wait"> method, but can give the process ID $pid and the options $options.
+Same as the L</"wait"> method, but can give the process ID $process_id and the options $options.
 
 See L<Sys::Process::Constant|SPVM::Sys::Process::Constant> about constant values given to $options.
 
@@ -1404,15 +1423,15 @@ If the system supports C<FD_CLOEXEC>, this flag is set to the value referenced b
 
 =head2 getpgrp
 
-C<static method getpgrp : int ($pid : int);>
+C<static method getpgrp : int ($process_id : int);>
 
-Gets the process group number given the process ID $pid of the running this program.
+Gets the process group number given the process ID $process_id of the running this program.
 
 =head2 setpgrp
 
-C<static method setpgrp : void ($pid : int, $pgid : int);>
+C<static method setpgrp : void ($process_id : int, $process_group_id : int);>
 
-Sets the process group number $pgid given the process ID $pid of the running this program.
+Sets the process group number $process_group_id given the process ID $process_id of the running this program.
 
 =head2 process_id
 
@@ -1440,49 +1459,97 @@ Examples:
 
 C<static method real_user_id : int ();>
 
-Gets the real user ID of this process.
+Gets the real user ID of the current process.
+
+This method calls L<Sys::User#getuid|SPVM::Sys::User/"getuid"> method and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#getuid|SPVM::Sys::User/"getuid"> method could be thrown.
 
 =head2 effective_user_id
 
 C<static method effective_user_id : int ();>
 
-Gets the effective user ID of this process.
+Gets the effective user ID of the current process.
+
+This method calls L<Sys::User#geteuid|SPVM::Sys::User/"geteuid"> method and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#geteuid|SPVM::Sys::User/"geteuid"> method could be thrown.
 
 =head2 real_group_id
 
 C<static method real_group_id : int ();>
 
-Gets the real group ID of this process.
+Gets the real group ID of the current process.
+
+This method calls L<Sys::User#getgid|SPVM::Sys::User/"getgid"> method and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#getgid|SPVM::Sys::User/"getgid"> method could be thrown.
 
 =head2 effective_group_id
 
 C<static method effective_group_id : int ();>
 
-Gets the effective group ID of this process.
+Gets the effective group ID of the current process.
+
+This method calls L<Sys::User#getegid|SPVM::Sys::User/"getegid"> method and returns its return value.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#getegid|SPVM::Sys::User/"getegid"> method could be thrown.
 
 =head2 set_real_user_id
 
-C<static method set_real_user_id : int ($uid : int);>
+C<static method set_real_user_id : void ($uid : int);>
 
-Sets the real user ID of this process.
+Sets the real user ID of the current process.
+
+This method calls L<Sys::User#setuid|SPVM::Sys::User/"setuid"> method given the argument given to this method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#setuid|SPVM::Sys::User/"setuid"> method could be thrown.
 
 =head2 set_effective_user_id
 
-C<static method set_effective_user_id : int ($euid : int);>
+C<static method set_effective_user_id : void ($euid : int);>
 
-Sets the effective user ID of this process.
+Sets the effective user ID of the current process.
+
+This method calls L<Sys::User#seteuid|SPVM::Sys::User/"seteuid"> method given the argument given to this method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#seteuid|SPVM::Sys::User/"seteuid"> method could be thrown.
 
 =head2 set_real_group_id
 
-C<static method set_real_group_id : int ($gid : int);>
+C<static method set_real_group_id : void ($real_group_id : int);>
 
-Sets the real group ID of this process.
+Sets the real group ID of the current process.
+
+This method calls L<Sys::User#setgid|SPVM::Sys::User/"setgid"> method given the argument given to this method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#setgid|SPVM::Sys::User/"setgid"> method could be thrown.
 
 =head2 set_effective_group_id
 
-C<static method set_effective_group_id : int ($egid : int);>
+C<static method set_effective_group_id : void ($effective_group_id : int);>
 
-Sets the effective group ID of this process.
+Sets the effective group ID of the current process.
+
+This method calls L<Sys::User#getegid|SPVM::Sys::User/"getegid"> method given the argument given to this method.
+
+Exceptions:
+
+Exceptions thrown by L<Sys::User#getegid|SPVM::Sys::User/"getegid"> method could be thrown.
 
 =head2 setpwent
 
@@ -1528,7 +1595,7 @@ Returns the supplementary group IDs of the calling process.
 
 =head2 setgroups
 
-C<static method setgroups : void ($groups : int[]);>
+C<static method setgroups : void ($group_ids : int[]);>
 
 Sets the supplementary group IDs for the calling process.
 
